@@ -23,6 +23,7 @@ JsonSchemaType = Literal["string", "number", "boolean", "object", "array", "butt
 
 
 class JsonBaseSchema(TypedDict):
+    type: JsonSchemaType
     key: NotRequired[Optional[str]]
     title: NotRequired[Optional[str]]
     description: NotRequired[Optional[str]]
@@ -42,7 +43,7 @@ class JsonBaseSchema(TypedDict):
 
 
 class JsonSchemaString(JsonBaseSchema):
-    type: Literal["string"]
+    type: Literal["string"]  # type: ignore
     format: NotRequired[
         Literal["date-time", "date", "time", "email", "uuid", "ipv4", "ipv6", "password", "qrCode", "image"]
     ]
@@ -51,34 +52,34 @@ class JsonSchemaString(JsonBaseSchema):
 
 
 class JsonSchemaNumber(JsonBaseSchema):
-    type: Literal["number"]
+    type: Literal["number"]  # type: ignore
     minimum: NotRequired[int]
     maximum: NotRequired[int]
     step: NotRequired[float]
 
 
 class JsonSchemaBoolean(JsonBaseSchema):
-    type: Literal["boolean"]
+    type: Literal["boolean"]  # type: ignore
 
 
 class JsonSchemaEnum(JsonBaseSchema):
-    type: Literal["string"]
+    type: Literal["string"]  # type: ignore
     enum: list[str]
     multiple: NotRequired[bool]
 
 
 class JsonSchemaButton(JsonBaseSchema):
-    type: Literal["button"]
+    type: Literal["button"]  # type: ignore
 
 
 class JsonSchemaObject(JsonBaseSchema):
-    type: Literal["object"]
+    type: Literal["object"]  # type: ignore
     opened: NotRequired[bool]
     properties: NotRequired["JsonSchemaForm"]
 
 
 class JsonSchemaArray(JsonBaseSchema):
-    type: Literal["array"]
+    type: Literal["array"]  # type: ignore
     opened: NotRequired[bool]
     items: NotRequired["JsonSchema"]
 
@@ -117,9 +118,14 @@ class SchemaConfig(TypedDict):
 
 
 # camera object
+class Go2RtcSource(TypedDict):
+    name: str
+    src: str
+
+
 class Go2RtcFFMPEGSource(TypedDict):
-    aac: str
-    opus: str
+    aac: Go2RtcSource
+    opus: Go2RtcSource
 
 
 class Go2RtcWSSource(TypedDict):
